.. pysoundanalyser documentation master file, created by
   sphinx-quickstart on Sun Sep 27 15:16:12 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pysoundanalyser's documentation!
===========================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   installation
   user_interface

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

